package ru.myitschool.work.ui.main

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch
import ru.myitschool.work.SessionManager
import ru.myitschool.work.api.ApiService
import javax.inject.Inject

@HiltViewModel
class MainViewModel @Inject constructor(
    private val apiService: ApiService
) : ViewModel() {
    private val _userInfoState = MutableStateFlow<Map<String, Any>?>(null)
    val userInfoState: StateFlow<Map<String, Any>?> = _userInfoState

    init {
        loadUserData()
    }

    private fun loadUserData() {
        viewModelScope.launch {
            try {
                val login = SessionManager.userLogin
                if (login != null) {
                    val response = apiService.getUserInfo(login)
                    if (response.isSuccessful) {
                        _userInfoState.value = response.body()
                    } else {
                        // Обработка ошибки, если ответ не успешен
                        _userInfoState.value = null // Или установите какое-то состояние ошибки
                    }
                } else {
                    // Логин равен null, обработайте это состояние
                    _userInfoState.value = null // Или установите какое-то состояние ошибки
                }
            } catch (e: Exception) {
                // Логирование ошибки
                e.printStackTrace()
                // Установите состояние ошибки
                _userInfoState.value = null // Или установите какое-то состояние ошибки
            }
        }
    }
}